/*
 * Copyright © 2011 Linaro Limited
 *
 * This file is part of glcompbench.
 *
 * glcompbench is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * glcompbench is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with glcompbench.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *  Alexandros Frantzis <alexandros.frantzis@linaro.org>
 *  Jesse Barker <jesse.barker@linaro.org>
 */

#ifndef COMPOSITE_CANVAS_XRENDER_H_
#define COMPOSITE_CANVAS_XRENDER_H_

#include "composite-canvas.h"

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/extensions/Xrender.h>
#include <X11/extensions/Xdbe.h>

class CompositeCanvasXRender: public CompositeCanvas
{
public:
    CompositeCanvasXRender() :
        CompositeCanvas("xrender"), xrender_picture_(0), xdbe_back_buffer_(0)
        {}

    virtual ~CompositeCanvasXRender();

    std::string info_string();
    Picture xrender_picture() { return xrender_picture_; }

protected:
    XVisualInfo *get_canvas_xvisualinfo();
    bool make_current();
    void release_resources();
    CompositeWindow *create_window(Window win);
    void update_screen();
    void reshape(int width, int height);

private:
    bool have_xdbe();
    bool have_xrender();
    bool ensure_xdbe_back_buffer();
    bool ensure_xrender_picture();

    Picture xrender_picture_;
    XdbeBackBuffer xdbe_back_buffer_;
};

#endif /* COMPOSITE_CANVAS_XRENDER_H_ */
